@@ -1,92 +1,47 @@
-"""Module for reading and writing MATLAB .mat files"""
-# Authors: Travis Oliphant, Matthew Brett
-
 """
 Module for reading and writing matlab (TM) .mat files
 """
+# Authors: Travis Oliphant, Matthew Brett
 
-import os
-import sys
-import warnings
+from __future__ import division, print_function, absolute_import
 
-from numpy.compat import asbytes
+from scipy._lib.six import string_types
 
-from miobase import get_matfile_version, docfiller
-from mio4 import MatFile4Reader, MatFile4Writer
-from mio5 import MatFile5Reader, MatFile5Writer
+from .miobase import get_matfile_version, docfiller
+from .mio4 import MatFile4Reader, MatFile4Writer
+from .mio5 import MatFile5Reader, MatFile5Writer
 
-__all__ = ['find_mat_file', 'mat_reader_factory', 'loadmat', 'savemat']
-
-@docfiller
-def find_mat_file(file_name, appendmat=True):
-    ''' Try to find .mat file on system path
-
-    Parameters
-    ----------
-    file_name : str
-       file name for mat file
-    %(append_arg)s
-
-    Returns
-    -------
-    full_name : string
-       possibly modified name after path search
-    '''
-    warnings.warn('Searching for mat files on python system path will be ' +
-                  'removed in next version of scipy',
-                   DeprecationWarning, stacklevel=2)
-    if appendmat and file_name.endswith(".mat"):
-        file_name = file_name[:-4]
-    if os.sep in file_name:
-        full_name = file_name
-        if appendmat:
-            full_name = file_name + ".mat"
-    else:
-        full_name = None
-        junk, file_name = os.path.split(file_name)
-        for path in [os.curdir] + list(sys.path):
-            test_name = os.path.join(path, file_name)
-            if appendmat:
-                test_name += ".mat"
-            try:
-                fid = open(test_name,'rb')
-                fid.close()
-                full_name = test_name
-                break
-            except IOError:
-                pass
-    return full_name
+__all__ = ['mat_reader_factory', 'loadmat', 'savemat', 'whosmat']
 
 
 def _open_file(file_like, appendmat):
-    ''' Open `file_like` and return as file-like object '''
-    if isinstance(file_like, basestring):
-        try:
-            return open(file_like, 'rb')
-        except IOError:
-            pass
-        if appendmat and not file_like.endswith('.mat'):
-            try:
-                return open(file_like + '.mat', 'rb')
-            except IOError:
-                pass
-        # search the python path - we'll remove this soon
-        full_name = find_mat_file(file_like, appendmat)
-        if full_name is None:
-            raise IOError("%s not found on the path."
-                          % file_like)
-        return open(full_name, 'rb')
-    # not a string - maybe file-like object
+    """
+    Open `file_like` and return as file-like object. First, check if object is
+    already file-like; if so, return it as-is. Otherwise, try to pass it
+    to open(). If that fails, and `file_like` is a string, and `appendmat` is true,
+    append '.mat' and try again.
+    """
     try:
         file_like.read(0)
+        return file_like, False
     except AttributeError:
-        raise IOError('Reader needs file name or open file-like object')
-    return file_like
+        pass
 
+    try:
+        return open(file_like, 'rb'), True
+    except IOError:
+        # Probably "not found"
+        if isinstance(file_like, string_types):
+            if appendmat and not file_like.endswith('.mat'):
+                file_like += '.mat'
+            return open(file_like, 'rb'), True
+        else:
+            raise IOError('Reader needs file name or open file-like object')
 
 @docfiller
 def mat_reader_factory(file_name, appendmat=True, **kwargs):
-    """Create reader for matlab .mat format files
+    """
+    Create reader for matlab .mat format files.
 
     Parameters
     ----------
@@ -100,29 +55,33 @@ def mat_reader_factory(file_name, appendmat=True, **kwargs):
     matreader : MatFileReader object
        Initialized instance of MatFileReader class matching the mat file
        type detected in `filename`.
+    file_opened : bool
+       Whether the file was opened by this routine.
+
     """
-    byte_stream = _open_file(file_name, appendmat)
+    byte_stream, file_opened = _open_file(file_name, appendmat)
     mjv, mnv = get_matfile_version(byte_stream)
     if mjv == 0:
-        return MatFile4Reader(byte_stream, **kwargs)
+        return MatFile4Reader(byte_stream, **kwargs), file_opened
     elif mjv == 1:
-        return MatFile5Reader(byte_stream, **kwargs)
+        return MatFile5Reader(byte_stream, **kwargs), file_opened
     elif mjv == 2:
         raise NotImplementedError('Please use HDF reader for matlab v7.3 files')
     else:
         raise TypeError('Did not recognize version %s' % mjv)
 
+
 @docfiller
-def loadmat(file_name,  mdict=None, appendmat=True, **kwargs):
+def loadmat(file_name, mdict=None, appendmat=True, **kwargs):
     """
-    Load MATLAB file
+    Load MATLAB file.
 
     Parameters
     ----------
     file_name : str
        Name of the mat file (do not need .mat extension if
-       appendmat==True) Can also pass open file-like object.
-    m_dict : dict, optional
+       appendmat==True). Can also pass open file-like object.
+    mdict : dict, optional
         Dictionary in which to insert matfile variables.
     appendmat : bool, optional
        True to append the .mat extension to the end of the given
@@ -148,10 +107,16 @@ def loadmat(file_name,  mdict=None, appendmat=True, **kwargs):
        False replicates the behavior of scipy version 0.7.x (returning
        numpy object arrays).  The default setting is True, because it
        allows easier round-trip load and save of MATLAB files.
+    verify_compressed_data_integrity : bool, optional
+        Whether the length of compressed sequences in the MATLAB file
+        should be checked, to ensure that they are not longer than we expect.
+        It is advisable to enable this (the default) because overlong
+        compressed sequences in MATLAB files generally indicate that the
+        files have experienced some sort of corruption.
     variable_names : None or sequence
         If None (the default) - read all variables in file. Otherwise
         `variable_names` should be a sequence of strings, giving names of the
-        matlab variables to read from the file.  The reader will skip any
+        MATLAB variables to read from the file.  The reader will skip any
         variable with a name not in this sequence, possibly saving some read
         processing.
 
@@ -159,35 +124,104 @@ def loadmat(file_name,  mdict=None, appendmat=True, **kwargs):
     -------
     mat_dict : dict
        dictionary with variable names as keys, and loaded matrices as
-       values
+       values.
 
     Notes
     -----
     v4 (Level 1.0), v6 and v7 to 7.2 matfiles are supported.
 
-    You will need an HDF5 python library to read matlab 7.3 format mat
+    You will need an HDF5 python library to read MATLAB 7.3 format mat
     files.  Because scipy does not supply one, we do not implement the
     HDF5 / 7.3 interface here.
 
+    Examples
+    --------
+    >>> from os.path import dirname, join as pjoin
+    >>> import scipy.io as sio
+
+    Get the filename for an example .mat file from the tests/data directory.
+
+    >>> data_dir = pjoin(dirname(sio.__file__), 'matlab', 'tests', 'data')
+    >>> mat_fname = pjoin(data_dir, 'testdouble_7.4_GLNX86.mat')
+
+    Load the .mat file contents.
+
+    >>> mat_contents = sio.loadmat(mat_fname)
+
+    The result is a dictionary, one key/value pair for each variable:
+
+    >>> sorted(mat_contents.keys())
+    ['__globals__', '__header__', '__version__', 'testdouble']
+    >>> mat_contents['testdouble']
+    array([[0.        , 0.78539816, 1.57079633, 2.35619449, 3.14159265,
+            3.92699082, 4.71238898, 5.49778714, 6.28318531]])
+
+    By default SciPy reads MATLAB structs as structured NumPy arrays where the
+    dtype fields are of type `object` and the names correspond to the MATLAB
+    struct field names. This can be disabled by setting the optional argument
+    `struct_as_record=False`.
+
+    Get the filename for an example .mat file that contains a MATLAB struct
+    called `teststruct` and load the contents.
+
+    >>> matstruct_fname = pjoin(data_dir, 'teststruct_7.4_GLNX86.mat')
+    >>> matstruct_contents = sio.loadmat(matstruct_fname)
+    >>> teststruct = matstruct_contents['teststruct']
+    >>> teststruct.dtype
+    dtype([('stringfield', 'O'), ('doublefield', 'O'), ('complexfield', 'O')])
+
+    The size of the structured array is the size of the MATLAB struct, not the
+    number of elements in any particular field. The shape defaults to 2-D
+    unless the optional argument `squeeze_me=True`, in which case all length 1
+    dimensions are removed.
+
+    >>> teststruct.size
+    1
+    >>> teststruct.shape
+    (1, 1)
+
+    Get the 'stringfield' of the first element in the MATLAB struct.
+
+    >>> teststruct[0, 0]['stringfield']
+    array(['Rats live on no evil star.'],
+      dtype='<U26')
+
+    Get the first element of the 'doublefield'.
+
+    >>> teststruct['doublefield'][0, 0]
+    array([[ 1.41421356,  2.71828183,  3.14159265]])
+
+    Load the MATLAB struct, squeezing out length 1 dimensions, and get the item
+    from the 'complexfield'.
+
+    >>> matstruct_squeezed = sio.loadmat(matstruct_fname, squeeze_me=True)
+    >>> matstruct_squeezed['teststruct'].shape
+    ()
+    >>> matstruct_squeezed['teststruct']['complexfield'].shape
+    ()
+    >>> matstruct_squeezed['teststruct']['complexfield'].item()
+    array([ 1.41421356+1.41421356j,  2.71828183+2.71828183j,
+        3.14159265+3.14159265j])
     """
     variable_names = kwargs.pop('variable_names', None)
-    MR = mat_reader_factory(file_name, appendmat, **kwargs)
+    MR, file_opened = mat_reader_factory(file_name, appendmat, **kwargs)
     matfile_dict = MR.get_variables(variable_names)
     if mdict is not None:
         mdict.update(matfile_dict)
     else:
         mdict = matfile_dict
-    if isinstance(file_name, basestring):
+    if file_opened:
         MR.mat_stream.close()
     return mdict
 
+
 @docfiller
 def savemat(file_name, mdict,
             appendmat=True,
             format='5',
             long_field_names=False,
             do_compression=False,
-            oned_as=None):
+            oned_as='row'):
     """
     Save a dictionary of names and arrays into a MATLAB-style .mat file.
 
@@ -207,52 +241,34 @@ def savemat(file_name, mdict,
         given filename, if not already present.
     format : {'5', '4'}, string, optional
         '5' (the default) for MATLAB 5 and up (to 7.2),
-        '4' for MATLAB 4 .mat files
+        '4' for MATLAB 4 .mat files.
     long_field_names : bool, optional
         False (the default) - maximum field name length in a structure is
         31 characters which is the documented maximum length.
         True - maximum field name length in a structure is 63 characters
-        which works for MATLAB 7.6+
+        which works for MATLAB 7.6+.
     do_compression : bool, optional
         Whether or not to compress matrices on write.  Default is False.
-    oned_as : {'column', 'row', None}, optional
+    oned_as : {'row', 'column'}, optional
         If 'column', write 1-D numpy arrays as column vectors.
         If 'row', write 1-D numpy arrays as row vectors.
-        If None (the default), the behavior depends on the value of `format`
-        (see Notes below).
 
     See also
     --------
     mio4.MatFile4Writer
     mio5.MatFile5Writer
-
-    Notes
-    -----
-    If ``format == '4'``, `mio4.MatFile4Writer` is called, which sets
-    `oned_as` to 'row' if it had been None.  If ``format == '5'``,
-    `mio5.MatFile5Writer` is called, which sets `oned_as` to 'column' if
-    it had been None, but first it executes:
-
-    ``warnings.warn("Using oned_as default value ('column')" +``
-                  ``" This will change to 'row' in future versions",``
-                  ``FutureWarning, stacklevel=2)``
-
-    without being more specific as to precisely when the change will take
-    place.
-
     """
-    file_is_string = isinstance(file_name, basestring)
-    if file_is_string:
-        if appendmat and file_name[-4:] != ".mat":
-            file_name = file_name + ".mat"
-        file_stream = open(file_name, 'wb')
-    else:
-        try:
-            file_name.write(asbytes(''))
-        except AttributeError:
-            raise IOError('Writer needs file name or writeable '
-                           'file-like object')
+    file_opened = False
+    if hasattr(file_name, 'write'):
+        # File-like object already; use as-is
         file_stream = file_name
+    else:
+        if isinstance(file_name, string_types):
+            if appendmat and not file_name.endswith('.mat'):
+                file_name = file_name + ".mat"
+
+        file_stream = open(file_name, 'wb')
+        file_opened = True
 
     if format == '4':
         if long_field_names:
@@ -267,5 +283,44 @@ def savemat(file_name, mdict,
     else:
         raise ValueError("Format should be '4' or '5'")
     MW.put_variables(mdict)
-    if file_is_string:
+    if file_opened:
         file_stream.close()
+
+
+@docfiller
+def whosmat(file_name, appendmat=True, **kwargs):
+    """
+    List variables inside a MATLAB file.
+
+    Parameters
+    ----------
+    %(file_arg)s
+    %(append_arg)s
+    %(load_args)s
+    %(struct_arg)s
+
+    Returns
+    -------
+    variables : list of tuples
+        A list of tuples, where each tuple holds the matrix name (a string),
+        its shape (tuple of ints), and its data class (a string).
+        Possible data classes are: int8, uint8, int16, uint16, int32, uint32,
+        int64, uint64, single, double, cell, struct, object, char, sparse,
+        function, opaque, logical, unknown.
+
+    Notes
+    -----
+    v4 (Level 1.0), v6 and v7 to 7.2 matfiles are supported.
+
+    You will need an HDF5 python library to read matlab 7.3 format mat
+    files.  Because scipy does not supply one, we do not implement the
+    HDF5 / 7.3 interface here.
+
+    .. versionadded:: 0.12.0
+
+    """
+    ML, file_opened = mat_reader_factory(file_name, **kwargs)
+    variables = ML.list_variables()
+    if file_opened:
+        ML.mat_stream.close()
+    return variables
