@@ -1,24 +1,19 @@
-""" Testing
+""" Testing mio5_utils Cython module
 
 """
+from __future__ import division, print_function, absolute_import
+
 import sys
 
-if sys.version_info[0] >= 3:
-    from io import BytesIO
-    cStringIO = BytesIO
-else:
-    from cStringIO import StringIO as cStringIO
-    from StringIO import StringIO as BytesIO
+from io import BytesIO
+cStringIO = BytesIO
 
 import numpy as np
 
-from numpy.compat import asbytes
+from numpy.testing import assert_array_equal, assert_equal, assert_
+from pytest import raises as assert_raises
 
-from nose.tools import assert_true, assert_false, \
-     assert_equal, assert_raises
-
-from numpy.testing import assert_array_equal, assert_array_almost_equal, \
-     run_module_suite
+from scipy._lib.six import u
 
 import scipy.io.matlab.byteordercodes as boc
 import scipy.io.matlab.streams as streams
@@ -34,9 +29,9 @@ def test_byteswap():
         a = np.array(val, dtype=np.uint32)
         b = a.byteswap()
         c = m5u.byteswap_u4(a)
-        yield assert_equal, b.item(), c
+        assert_equal(b.item(), c)
         d = m5u.byteswap_u4(c)
-        yield assert_equal, a.item(), d
+        assert_equal(a.item(), d)
 
 
 def _make_tag(base_dt, val, mdtype, sde=False):
@@ -52,14 +47,14 @@ def _make_tag(base_dt, val, mdtype, sde=False):
                   ('val', base_dt)]
         if padding:
             all_dt.append(('padding', 'u1', padding))
-    else: # is sde
+    else:  # is sde
         udt = bo + 'u2'
         padding = 4-byte_count
-        if bo == '<': # little endian
+        if bo == '<':  # little endian
             all_dt = [('mdtype', udt),
                       ('byte_count', udt),
                       ('val', base_dt)]
-        else: # big endian
+        else:  # big endian
             all_dt = [('byte_count', udt),
                       ('mdtype', udt),
                       ('val', base_dt)]
@@ -101,12 +96,12 @@ def test_read_tag():
     r = _make_readerlike(str_io)
     c_reader = m5u.VarReader5(r)
     # This works for StringIO but _not_ cStringIO
-    yield assert_raises, IOError, c_reader.read_tag
+    assert_raises(IOError, c_reader.read_tag)
     # bad SDE
     tag = _make_tag('i4', 1, mio5p.miINT32, sde=True)
     tag['byte_count'] = 5
     _write_stream(str_io, tag.tostring())
-    yield assert_raises, ValueError, c_reader.read_tag
+    assert_raises(ValueError, c_reader.read_tag)
 
 
 def test_read_stream():
@@ -115,7 +110,7 @@ def test_read_stream():
     str_io = cStringIO(tag_str)
     st = streams.make_stream(str_io)
     s = streams._read_into(st, tag.itemsize)
-    yield assert_equal, s, tag.tostring()
+    assert_equal(s, tag.tostring())
 
 
 def test_read_numeric():
@@ -123,28 +118,27 @@ def test_read_numeric():
     str_io = cStringIO()
     r = _make_readerlike(str_io)
     # check simplest of tags
-    for base_dt, val, mdtype in (
-        ('u2', 30, mio5p.miUINT16),
-        ('i4', 1, mio5p.miINT32),
-        ('i2', -1, mio5p.miINT16)):
+    for base_dt, val, mdtype in (('u2', 30, mio5p.miUINT16),
+                                 ('i4', 1, mio5p.miINT32),
+                                 ('i2', -1, mio5p.miINT16)):
         for byte_code in ('<', '>'):
             r.byte_order = byte_code
             c_reader = m5u.VarReader5(r)
-            yield assert_equal, c_reader.little_endian, byte_code == '<'
-            yield assert_equal, c_reader.is_swapped, byte_code != boc.native_code
+            assert_equal(c_reader.little_endian, byte_code == '<')
+            assert_equal(c_reader.is_swapped, byte_code != boc.native_code)
             for sde_f in (False, True):
                 dt = np.dtype(base_dt).newbyteorder(byte_code)
                 a = _make_tag(dt, val, mdtype, sde_f)
                 a_str = a.tostring()
                 _write_stream(str_io, a_str)
                 el = c_reader.read_numeric()
-                yield assert_equal, el, val
+                assert_equal(el, val)
                 # two sequential reads
                 _write_stream(str_io, a_str, a_str)
                 el = c_reader.read_numeric()
-                yield assert_equal, el, val
+                assert_equal(el, val)
                 el = c_reader.read_numeric()
-                yield assert_equal, el, val
+                assert_equal(el, val)
 
 
 def test_read_numeric_writeable():
@@ -157,14 +151,14 @@ def test_read_numeric_writeable():
     a_str = a.tostring()
     _write_stream(str_io, a_str)
     el = c_reader.read_numeric()
-    yield assert_true, el.flags.writeable
+    assert_(el.flags.writeable is True)
 
 
 def test_zero_byte_string():
     # Tests hack to allow chars of non-zero length, but 0 bytes
     # make reader-like thing
     str_io = cStringIO()
-    r = _make_readerlike(str_io, '<')
+    r = _make_readerlike(str_io, boc.native_code)
     c_reader = m5u.VarReader5(r)
     tag_dt = np.dtype([('mdtype', 'u4'), ('byte_count', 'u4')])
     tag = np.zeros((1,), dtype=tag_dt)
@@ -173,22 +167,19 @@ def test_zero_byte_string():
     hdr = m5u.VarHeader5()
     # Try when string is 1 length
     hdr.set_dims([1,])
-    _write_stream(str_io, tag.tostring() + asbytes('        '))
+    _write_stream(str_io, tag.tostring() + b'        ')
     str_io.seek(0)
     val = c_reader.read_char(hdr)
-    assert_equal(val, u' ')
+    assert_equal(val, u(' '))
     # Now when string has 0 bytes 1 length
     tag['byte_count'] = 0
     _write_stream(str_io, tag.tostring())
     str_io.seek(0)
     val = c_reader.read_char(hdr)
-    assert_equal(val, u' ')
+    assert_equal(val, u(' '))
     # Now when string has 0 bytes 4 length
     str_io.seek(0)
     hdr.set_dims([4,])
     val = c_reader.read_char(hdr)
-    assert_array_equal(val, [u' '] * 4)
+    assert_array_equal(val, [u(' ')] * 4)
 
-
-if __name__ == "__main__":
-    run_module_suite()
