@@ -1,11 +1,12 @@
-#!/usr/bin/env python
+from __future__ import division, print_function, absolute_import
 
 from os.path import join
 
+
 def configuration(parent_package='', top_path=None):
     import warnings
     from numpy.distutils.misc_util import Configuration
-    from numpy.distutils.system_info import get_info, BlasNotFoundError
+    from scipy._build_utils.system_info import get_info, BlasNotFoundError
     config = Configuration('odr', parent_package, top_path)
 
     libodr_files = ['d_odr.f',
@@ -19,8 +20,9 @@ def configuration(parent_package='', top_path=None):
         warnings.warn(BlasNotFoundError.__doc__)
         libodr_files.append('d_lpkbls.f')
 
-    libodr = [join('odrpack', x) for x in libodr_files]
-    config.add_library('odrpack', sources=libodr)
+    odrpack_src = [join('odrpack', x) for x in libodr_files]
+    config.add_library('odrpack', sources=odrpack_src)
+
     sources = ['__odrpack.c']
     libraries = ['odrpack'] + blas_info.pop('libraries', [])
     include_dirs = ['.'] + blas_info.pop('include_dirs', [])
@@ -28,13 +30,14 @@ def configuration(parent_package='', top_path=None):
         sources=sources,
         libraries=libraries,
         include_dirs=include_dirs,
-        depends=['odrpack.h'],
+        depends=(['odrpack.h'] + odrpack_src),
         **blas_info
     )
 
     config.add_data_dir('tests')
     return config
 
+
 if __name__ == '__main__':
     from numpy.distutils.core import setup
     setup(**configuration(top_path='').todict())
